Article View: gnu.gdb.bug
Article #10172GDB fastness (for a change :-)
From: Bryan Boreham
Date: Sun, 08 Apr 1990 16:23
Date: Sun, 08 Apr 1990 16:23
19 lines
1206 bytes
1206 bytes
In article <9004060947.AA10950@pogo>, kingdon@AI.MIT.EDU (Jim Kingdon) writes: > Here is a patch which I think helps GDB performance. And it does! Massively! A little test came down in real time from 24s to 12s, and this is *with* the -fminimal-debug stuff! No increase in virtual or resident size was noticeable. Boy, could we have done with that patch eight months ago... One little SNAFU: the 'stsize' variable referenced in symbol_file_command is not declared in that function. I think 'buffer' was meant. I guess other people's mileage may vary, but thanks a lot for this patch, Jim. Bryan.
Technical Details
Message-ID:
<9004081623.AA22470@kewill.uucp>Path:
arc1-ca.pugleaf.net!gmdzi!unido!mcsun!uunet!tut.cis.ohio-state.edu!relay.eu.net!kewill!bryanShow Full Headers
Complete Article Headers
X-Google-Language: ENGLISH,ASCII-7-bit X-Google-Thread: f5053,4ffb5b91f68dcff4,start X-Google-Attributes: gidf5053,public X-Google-ArrivalTime: 1990-04-08 23:41:45 PST Path: arc1-ca.pugleaf.net!gmdzi!unido!mcsun!uunet!tut.cis.ohio-state.edu!relay.eu.net!kewill!bryan From: kewill!bryan@relay.eu.net (Bryan Boreham) Newsgroups: gnu.gdb.bug Subject: GDB fastness (for a change :-) Message-ID: <9004081623.AA22470@kewill.uucp> Date: 8 Apr 90 16:23:39 GMT Sender: daemon@tut.cis.ohio-state.edu Distribution: gnu Organization: GNUs Not Usenet Lines: 19 Posted: Sun Apr 8 17:23:39 1990